Detect ADaM class for each dataset in a named list or spec
Source:R/sub-discover.R
detect_adam_classes.RdApplies detect_adam_class to every dataset, accepting either
a named list of data frames or a herald_spec object.
See also
Other specification:
apply_spec(),
coerce_types(),
decode_var(),
detect_adam_class(),
drop_unspec_vars(),
herald_spec(),
order_cols(),
read_spec(),
read_spec_define(),
scaffold_vars(),
sort_keys(),
spec_codelist(),
spec_datasets(),
spec_study(),
spec_vars(),
write_define_html(),
write_define_xml(),
write_spec()
Examples
adsl <- data.frame(STUDYID = "S1", USUBJID = "S1-001", AGE = 65L)
advs <- data.frame(USUBJID = "S1-001", PARAMCD = "SYSBP", AVAL = 120)
adae <- data.frame(USUBJID = "S1-001", AETERM = "Headache", AEDECOD = "Headache")
adtte <- data.frame(USUBJID = "S1-001", PARAMCD = "OS", AVAL = 180, CNSR = 0L)
detect_adam_classes(list(ADSL = adsl, ADVS = advs, ADAE = adae, ADTTE = adtte))
#> ADSL ADVS ADAE ADTTE
#> "ADSL" "BDS" "OCCDS" "TTE"