Skip to contents

Returns the path to the local directory where herald caches validation rules downloaded from the herald-rules GitHub repository. Use fetch_herald_rules() to populate this directory.

Usage

herald_rules_cache_dir()

Value

Character scalar: the full path to the cache directory (which may not yet exist if rules have not been downloaded).

Examples

herald_rules_cache_dir()
#> [1] "/tmp/RtmpB1uFfd/temp_libpath3fd56a551ee9/herald/rules"