Skip to contents

Returns a data frame summarising the CT packages currently registered in the session via register_ct().

Usage

list_ct()

Value

A data frame with columns name and path, or an empty data frame when no CT is registered.

Examples

list_ct()
#> [1] name path
#> <0 rows> (or 0-length row.names)