Return the cache directory used by herald for validation rules
Source:R/rule-fetch.R
herald_rules_cache_dir.RdReturns the path to the local directory where herald caches validation rules
downloaded from the herald-rules GitHub repository. Use
fetch_herald_rules() to populate this directory.
Value
Character scalar: the full path to the cache directory (which may not yet exist if rules have not been downloaded).
See also
fetch_herald_rules() to download rules.
Other conformance:
adam_rules(),
build_anchor_index(),
clear_ct(),
fda_rules(),
fetch_core_rules(),
fetch_herald_rules(),
list_ct(),
load_herald_config(),
new_herald_context(),
pmda_rules(),
register_ct(),
register_operator(),
rule_catalog(),
rule_config(),
update_core_rules(),
validate(),
validate_spec(),
validate_spec_define(),
validation_report(),
verify_html_report()